/* OperStats Help Files

   OperStats - Copyright (c) 2000-2002 Darcy Grexton
   Contact: skold@habber.net, skold @ HabberNet, ICQ #6285178

   This program is free but copyrighted software; see the file COPYING
   for details.
 */

#include "../inc/operstats.h"

void statserv_help_index (const char *source)
{
    notice (s_StatServ, source, RPL_HELP_START, s_StatServ);
    notice (s_StatServ, source, " ");
    notice (s_StatServ, source, "\2%s\2 monitors the network in various ways, and",
	s_StatServ);
    notice (s_StatServ, source, "provides statistics about the network and its users.");
    notice (s_StatServ, source, " ");
    notice (s_StatServ, source, "For more information on a specific topic, type:");
    notice (s_StatServ, source, "/%s%s%s%s HELP Topic\2", haveserv_on == TRUE ? "" :
	"MSG ", s_StatServ, haveserv_on == TRUE ? "" : securitysetting == 1 ? "@" :
	"", haveserv_on == TRUE ? "" : securitysetting == 1 ? me.name : "");
    notice (s_StatServ, source, " ");
    notice (s_StatServ, source, "\2%s\2 contains information on the following topics:",
	s_StatServ);
    notice (s_StatServ, source, " ");

    if (shorthelp_on == TRUE)
    {
	char buf[BUFSIZE];

	*buf = 0;

	notice (s_StatServ, source, "\2STATS MAP SERVERS%s%s%s%s\2",
	    tldlookup == TRUE ? " TLD" : "", tldlookup == TRUE ? " TLDMAP" : "",
	    tldlookup == TRUE ? " TLDSTATS" : "", zonelookup == TRUE ? " ZONE" : "");

	if (operserv_on == FALSE && is_oper (source))
	    strcat (buf, "SEARCH AUTH");

	if (operserv_on == FALSE && is_sra (source))
	    strcat (buf, " DEAUTH SHUTDOWN RESTART");

#ifdef RAWINJECT
	if (operserv_on == FALSE && is_sra (source))
	    strcat (buf, " RAW INJECT");
#endif

	if (*buf)
	    notice (s_StatServ, source, "\2%s\2", buf);

	*buf = 0;

	if (operserv_on == FALSE && is_sra (source))
	    strcat (buf, "DEBUG UPDATE REHASH SETTINGS ");

	if (is_sra (source))
	    strcat (buf, "FLUSH RESET SENDPINGS");

	if (*buf)
	    notice (s_StatServ, source, "\2%s\2", buf);
    }
    else
    {
	notice (s_StatServ, source, "\2STATS\2           Show statistics on the network");
	notice (s_StatServ, source, "\2MAP\2             Show a map of the network");
	notice (s_StatServ, source, "\2SERVERS\2         Show a listing of servers and versions");
	if (tldlookup == TRUE)
	{
	    notice (s_StatServ, source, "\2TLD\2             Show the country associated with a TLD");
	    notice (s_StatServ, source, "\2TLDMAP\2          Show per-TLD user counts");
	    notice (s_StatServ, source, "\2TLDSTATS\2        Show per-TLD daily stats");
	}
	if (zonelookup == TRUE)
	    notice (s_StatServ, source, "\2ZONE\2            Perform a TimeZone lookup");
	if (operserv_on == FALSE && is_oper (source))
	{
	    notice (s_StatServ, source, "\2SEARCH\2          Search OperStats's logfile");
	    notice (s_StatServ, source, "\2AUTH\2            Authenticate as an SRA");
	}
	if (operserv_on == FALSE && is_sra (source))
	{
	    notice (s_StatServ, source, "\2DEAUTH\2          De-Authenticate as an SRA");
	    notice (s_StatServ, source, "\2SHUTDOWN\2        Terminate OperStats");
	    notice (s_StatServ, source, "\2RESTART\2         Restart OperStats");
#ifdef RAWINJECT
	    notice (s_StatServ, source, "\2RAW\2             Send information to the uplink");
	    notice (s_StatServ, source, "\2INJECT\2          Fake information from the uplink");
#endif
	    notice (s_StatServ, source, "\2DEBUG\2           Set debugging level");
	    notice (s_StatServ, source, "\2UPDATE\2          Force a database update");
	    notice (s_StatServ, source, "\2REHASH\2          Re-Read %s", CONFIGFILE);
	    notice (s_StatServ, source, "\2SETTINGS\2        Show various OperStats settings");
	}
	if (is_sra (source))
	{
	    notice (s_StatServ, source, "\2FLUSH\2           Flush a server from memory");
	    notice (s_StatServ, source, "\2RESET\2           Reset one or all server's statistics");
	    notice (s_StatServ, source, "\2SENDPINGS\2       Force an update of %s's lag times",
		s_StatServ);
	}
    }

    notice (s_StatServ, source, " ");
    notice (s_StatServ, source, RPL_HELP_END);
}

void statserv_help_stats (const char *source)
{
    notice (s_StatServ, source, RPL_HELP_START, s_StatServ);
    notice (s_StatServ, source, " ");

    if (is_oper (source))
	notice (s_StatServ, source, "Syntax: \2STATS [+CMNUD|Server]\2");
    else
	notice (s_StatServ, source, "Syntax: \2STATS [+CMNUD]\2");

    notice (s_StatServ, source, " ");
    notice (s_StatServ, source, "Shows various information about the network, such as how many");
    notice (s_StatServ, source, "users servers and channels there are, how fast the network is");
    notice (s_StatServ, source, "running, and max user, server and channel counts. \2STATS\2 also");
    notice (s_StatServ, source, "shows daily channel, user and server records, and when they were");
    notice (s_StatServ, source, "set during the day. These stats are reset at midnight, GMT.");
    notice (s_StatServ, source, " ");
    notice (s_StatServ, source, "If any of the tokens CMNUD are given, the STATS output is filtered");
    notice (s_StatServ, source, "to match these tokens. The token string must be preceded by a +.");
    notice (s_StatServ, source, "Each token corresponds to a particular part of the full STATS output:");
    notice (s_StatServ, source, "     C - Show Current Stats (Users, Channels, Servers, Time)");
    notice (s_StatServ, source, "     M - Show Max Stats (Users, Channels, Servers, Hits, and Times)");
    notice (s_StatServ, source, "     N - Show NetSpeed Stat");
    notice (s_StatServ, source, "     U - Show Uptime Stat");
    notice (s_StatServ, source, "     D - Show Daily Stats (Hits, Users, Channels, Servers)");
    notice (s_StatServ, source, " ");

    if (is_oper (source))
    {
	notice (s_StatServ, source, "If you provide a server name, statistics for that server will");
	notice (s_StatServ, source, "be shown.");
	notice (s_StatServ, source, " ");
    }

    notice (s_StatServ, source, "Examples: \2STATS\2");
    notice (s_StatServ, source, "          \2STATS +CMNUD\2");

    if (is_oper (source))
	notice (s_StatServ, source, "          \2STATS server.*\2");

    notice (s_StatServ, source, " ");
    notice (s_StatServ, source, RPL_HELP_END);
}

void statserv_help_tld (const char *source)
{
    notice (s_StatServ, source, RPL_HELP_START, s_StatServ);
    notice (s_StatServ, source, " ");
    notice (s_StatServ, source, "Syntax: \2TLD TopLevelDomain|Country\2");
    notice (s_StatServ, source, " ");
    notice (s_StatServ, source, "Show which country or organization a given top-level domain");
    notice (s_StatServ, source, "represents. \2%s\2 will match the TLD with wildcards, so", s_StatServ);
    notice (s_StatServ, source, "providing a domain may give a false match. Additionally, you may");
    notice (s_StatServ, source, "give the name of the country to see which TLD is associated with it.");
    notice (s_StatServ, source, " ");
    notice (s_StatServ, source, "Examples: \2TLD ca\2");
    notice (s_StatServ, source, "          \2TLD Canada\2");
    notice (s_StatServ, source, " ");
    notice (s_StatServ, source, RPL_HELP_END);
}

void statserv_help_tldmap (const char *source)
{
    notice (s_StatServ, source, RPL_HELP_START, s_StatServ);
    notice (s_StatServ, source, " ");
    notice (s_StatServ, source, "Syntax: \2TLDMAP [TLD]\2");
    notice (s_StatServ, source, " ");
    notice (s_StatServ, source, "Shows you the user counts per top-level-domain. If you specify");
    notice (s_StatServ, source, "a TLD, only that TLD will be shown.");
    notice (s_StatServ, source, " ");
    notice (s_StatServ, source, "Examples: \2TLDMAP\2");
    notice (s_StatServ, source, "          \2TLDMAP net\2");
    notice (s_StatServ, source, " ");
    notice (s_StatServ, source, RPL_HELP_END);
}

void statserv_help_tldstats (const char *source)
{
    notice (s_StatServ, source, RPL_HELP_START, s_StatServ);
    notice (s_StatServ, source, " ");
    notice (s_StatServ, source, "Syntax: \2TLDSTATS [TLD]\2");
    notice (s_StatServ, source, " ");
    notice (s_StatServ, source, "Shows you the daily hit counts per top-level-domain. If you");
    notice (s_StatServ, source, "specify a TLD, only that TLD will be shown.");
    notice (s_StatServ, source, " ");
    notice (s_StatServ, source, "Examples: \2TLDSTATS\2");
    notice (s_StatServ, source, "          \2TLDSTATS net\2");
    notice (s_StatServ, source, " ");
    notice (s_StatServ, source, RPL_HELP_END);
}

void statserv_help_zone (const char *source)
{
    notice (s_StatServ, source, RPL_HELP_START, s_StatServ);
    notice (s_StatServ, source, " ");
    notice (s_StatServ, source, "Syntax: \2ZONE TimeZone\2");
    notice (s_StatServ, source, " ");
    notice (s_StatServ, source, "Performs a TimeZone lookup. If the TimeZone is found, the");
    notice (s_StatServ, source, "TimeZone name, GMT Offset, and current time will be displayed.");
    notice (s_StatServ, source, " ");
    notice (s_StatServ, source, "Note that several TimeZones share the same abbreviation, so you");
    notice (s_StatServ, source, "may get more than one result.");
    notice (s_StatServ, source, " ");
    notice (s_StatServ, source, "Also remember Daylight Savings Time; PDT and PST are NOT the");
    notice (s_StatServ, source, "same thing! Depending on the time of year, either one may be");
    notice (s_StatServ, source, "correct.");
    notice (s_StatServ, source, " ");
    notice (s_StatServ, source, "Example: \2ZONE GMT\2");
    notice (s_StatServ, source, " ");
    notice (s_StatServ, source, RPL_HELP_END);
}

void statserv_help_map (const char *source)
{
    notice (s_StatServ, source, RPL_HELP_START, s_StatServ);
    notice (s_StatServ, source, " ");
    notice (s_StatServ, source, "Syntax: \2MAP\2");
    notice (s_StatServ, source, " ");
    notice (s_StatServ, source, "Shows a map of how the network is currently structured. A breakdown");
    notice (s_StatServ, source, "of the users-per-server and the server's current ping time are also");
    notice (s_StatServ, source, "included.");
    notice (s_StatServ, source, " ");
    notice (s_StatServ, source, "Example: \2MAP\2");
    notice (s_StatServ, source, " ");
    notice (s_StatServ, source, RPL_HELP_END);
}

void statserv_help_servers (const char *source)
{
    notice (s_StatServ, source, RPL_HELP_START, s_StatServ);
    notice (s_StatServ, source, " ");
    notice (s_StatServ, source, "Syntax: \2SERVERS\2");
    notice (s_StatServ, source, " ");
    notice (s_StatServ, source, "Shows a list of the servers currently on the network, what");
    notice (s_StatServ, source, "version of IRCd they are running, and how they are configured.");
    notice (s_StatServ, source, " ");
    notice (s_StatServ, source, "Example: \2SERVERS\2");
    notice (s_StatServ, source, " ");
    notice (s_StatServ, source, RPL_HELP_END);
}

void statserv_help_sendpings (const char *source)
{
    notice (s_StatServ, source, RPL_HELP_START, s_StatServ);
    notice (s_StatServ, source, " ");
    notice (s_StatServ, source, "Syntax: \2SENDPINGS\2");
    notice (s_StatServ, source, " ");
    notice (s_StatServ, source, "Forces %s to update it's lag times for MAP. All", s_StatServ);
    notice (s_StatServ, source, "servers will be pinged simultaneously, and this may cause a");
    notice (s_StatServ, source, "small lag spike. The PING times are updated automatically as");
    notice (s_StatServ, source, "defined in %s.", CONFIGFILE);
    notice (s_StatServ, source, " ");
    notice (s_StatServ, source, "Example: \2SENDPINGS\2");
    notice (s_StatServ, source, " ");
    notice (s_StatServ, source, RPL_HELP_END);
}

void statserv_help_flush (const char *source)
{
    notice (s_StatServ, source, RPL_HELP_START, s_StatServ);
    notice (s_StatServ, source, " ");
    notice (s_StatServ, source, "Syntax: \2FLUSH Server\2");
    notice (s_StatServ, source, " ");
    notice (s_StatServ, source, "Removes a server from memory. This should only be used when");
    notice (s_StatServ, source, "the server has permanently left the network. The server will");
    notice (s_StatServ, source, "be re-entered into memory if it is seen again. If you want to");
    notice (s_StatServ, source, "reset a server's statistics, see the \2RESET\2 command.");
    notice (s_StatServ, source, " ");
    notice (s_StatServ, source, "Example: \2FLUSH server.example.net\2");
    notice (s_StatServ, source, " ");
    notice (s_StatServ, source, RPL_HELP_END);
}

void statserv_help_reset (const char *source)
{
    notice (s_StatServ, source, RPL_HELP_START, s_StatServ);
    notice (s_StatServ, source, " ");
    notice (s_StatServ, source, "Syntax: \2RESET Server|All\2");
    notice (s_StatServ, source, " ");
    notice (s_StatServ, source, "Resets the given server's statistics. This will not remove the");
    notice (s_StatServ, source, "server from memory, only reset its stats. If you want to remove");
    notice (s_StatServ, source, "a server (i.e., in the event of a delink), see the \2FLUSH\2 command.");
    notice (s_StatServ, source, " ");
    notice (s_StatServ, source, "If you give \2ALL\2 in place of a server name, then statistics for");
    notice (s_StatServ, source, "all servers will be reset.");
    notice (s_StatServ, source, " ");
    notice (s_StatServ, source, "Examples: \2RESET server.example.net\2");
    notice (s_StatServ, source, "          \2RESET ALL\2");
    notice (s_StatServ, source, " ");
    notice (s_StatServ, source, RPL_HELP_END);
}

void operserv_help_index (const char *source)
{
    notice (s_OperServ, source, RPL_HELP_START, s_OperServ);
    notice (s_OperServ, source, " ");
    notice (s_OperServ, source, "\2%s\2 gives IRC Operators greater control over", s_OperServ);
    notice (s_OperServ, source, "the network through the use of JUPEs, AKILLs, and other");
    notice (s_OperServ, source, "commands.");
    notice (s_OperServ, source, " ");
    notice (s_OperServ, source, "For more information on a specific topic, type:");
    notice (s_OperServ, source, "/%s%s%s%s HELP Topic\2", haveserv_on == TRUE ? "" :
	"MSG ", s_OperServ, haveserv_on == TRUE ? "" : securitysetting == 1 ? "@" :
	"", haveserv_on == TRUE ? "" : securitysetting == 1 ? me.name : "");
    notice (s_OperServ, source, " ");
    notice (s_OperServ, source, "\2%s\2 contains information on the following topics:",
	s_OperServ);
    notice (s_OperServ, source, " ");

    if (shorthelp_on == TRUE)
    {
	char buf[BUFSIZE];

	*buf = 0;

	/* Use strcat to build a buffer. When the buffer is > 40, send it out. */
	strcat (buf, "JUPE AKILL SEARCH AUTH");

	if (maxclones)
	    strcat (buf, " CLONES TRIGGER EXCEPTION");

	if (globalnoticer_on == TRUE)
	    strcat (buf, " GLOBAL");

	/* It could be up to 54 chars now. Check if it is. */
	if (strlen (buf) > 40)
	{
	    notice (s_OperServ, source, "\2%s\2", buf);
	    *buf = 0;
	}

	if (is_sra (source))
	{
	    if (*buf)
		strcat (buf, " ");

	    /* Do two at a time, then check, to keep from getting too large a buffer. */
	    strcat (buf, "DEAUTH SHUTDOWN");

	    if (strlen (buf) > 40)
	    {
		notice (s_OperServ, source, "\2%s\2", buf);
		*buf = 0;
	    }

	    if (*buf)
		strcat (buf, " ");

	    /* We can fit 3 here.. */
	    strcat (buf, "RESTART DEBUG UPDATE");

	    if (strlen (buf) > 40)
	    {
		notice (s_OperServ, source, "\2%s\2", buf);
		*buf = 0;
	    }

	    if (*buf)
		strcat (buf, " ");

#ifdef RAWINJECT
	    strcat (buf, "RAW INJECT");
#endif

	    if (strlen (buf) > 40)
	    {
		notice (s_OperServ, source, "\2%s\2", buf);
		*buf = 0;
	    }

	    if (*buf)
		strcat (buf, " ");

	    /* We'll do three here too, no point having LOGONMSG all on its own. */
	    strcat (buf, "REHASH SETTINGS LOGONMSG");

	    notice (s_OperServ, source, "\2%s\2", buf);
	}
    }
    else
    {
	notice (s_OperServ, source, "\2JUPE\2            Jupiter a server or nick");
	notice (s_OperServ, source, "\2AKILL\2           Add, Remove, or List AutoKills");

	if (maxclones)
	{
	    notice (s_OperServ, source, "\2CLONES\2          List the current clones on the network");
	    notice (s_OperServ, source, "\2TRIGGER\2         Add, Remove, or List Triggers");
	    notice (s_OperServ, source, "\2EXCEPTION\2       Add, Remove, or List Exceptions");
	}

	notice (s_OperServ, source, "\2SEARCH\2          Search OperStats's logfile");
	notice (s_OperServ, source, "\2AUTH\2            Authenticate as an SRA");

	if (globalnoticer_on == TRUE)
	    notice (s_OperServ, source, "\2GLOBAL\2          Send a global notice");

	if (is_sra (source))
	{
	    notice (s_OperServ, source, "\2DEAUTH\2          De-Authenticate as an SRA");
	    notice (s_OperServ, source, "\2SHUTDOWN\2        Terminate OperStats");
	    notice (s_OperServ, source, "\2RESTART\2         Restart OperStats");
#ifdef RAWINJECT
	    notice (s_OperServ, source, "\2RAW\2             Send information to the uplink");
	    notice (s_OperServ, source, "\2INJECT\2          Fake information from the uplink");
#endif
	    notice (s_OperServ, source, "\2DEBUG\2           Set debugging level");
	    notice (s_OperServ, source, "\2UPDATE\2          Force a database update");
	    notice (s_OperServ, source, "\2REHASH\2          Re-Read %s", CONFIGFILE);
	    notice (s_OperServ, source, "\2SETTINGS\2        Show various OperStats settings");

	    if (globalnoticer_on == TRUE)
		notice (s_OperServ, source, "\2LOGONMSG\2        Add, Remove, or List LogonMSGs");
	}
    }

    notice (s_OperServ, source, " ");
    notice (s_OperServ, source, RPL_HELP_END);
}

void operserv_help_global (const char *source)
{
    notice (s_OperServ, source, RPL_HELP_START, s_OperServ);
    notice (s_OperServ, source, " ");
    notice (s_OperServ, source, "Syntax: \2GLOBAL Message\2");
    notice (s_OperServ, source, " ");
    notice (s_OperServ, source, "Sends a global notice. If your TLD setting is correct, all users");
    notice (s_OperServ, source, "on the network will see the notice.");
    notice (s_OperServ, source, " ");
    notice (s_OperServ, source, "Example: \2GLOBAL We are doing some routing, There will be a short split.\2");
    notice (s_OperServ, source, " ");
    notice (s_OperServ, source, RPL_HELP_END);
}

void operserv_help_jupe (const char *source)
{
    notice (s_OperServ, source, RPL_HELP_START, s_OperServ);
    notice (s_OperServ, source, " ");
    notice (s_OperServ, source, "Syntax: \2JUPE Server|User [Reason]\2");
    notice (s_OperServ, source, " ");
    notice (s_OperServ, source, "Jupiters the specified server or user. This will remove");
    notice (s_OperServ, source, "the server or user from the network if it already exists.");
    notice (s_OperServ, source, "Jupes will remain in place until SQUIT/KILLed, or until");
    notice (s_OperServ, source, "OperStats is reset. If a reason is given, it will be used");
    notice (s_OperServ, source, "in any SQUIT/KILL of an existing server/user, and in the");
    notice (s_OperServ, source, "jupe's description/realname.");
    notice (s_OperServ, source, " ");
    notice (s_OperServ, source, "Examples: \2JUPE server.example.net Delinked\2");
    notice (s_OperServ, source, "          \2JUPE someuser This nick may not be used.\2");
    notice (s_OperServ, source, " ");
    notice (s_OperServ, source, RPL_HELP_END);
}

void operserv_help_clones (const char *source)
{
    notice (s_OperServ, source, RPL_HELP_START, s_OperServ);
    notice (s_OperServ, source, " ");
    notice (s_OperServ, source, "Syntax: \2CLONES Pattern [Limit]\2");
    notice (s_OperServ, source, " ");
    notice (s_OperServ, source, "Lists the current clones on the network. Only hostnames matching");
    notice (s_OperServ, source, "Pattern will be shown. Use * to show all clones. If you give Limit,");
    notice (s_OperServ, source, "only Limit matching hosts will be shown.");
    notice (s_OperServ, source, " ");
    notice (s_OperServ, source, "Regardless of the given Limit, no more than 250 matches will be shown.");
    notice (s_OperServ, source, " ");
    notice (s_OperServ, source, "Examples: \2CLONES *hostname.com 25\2");
    notice (s_OperServ, source, "          \2CLONES *\2");
    notice (s_OperServ, source, " ");
    notice (s_OperServ, source, RPL_HELP_END);
}

void operserv_help_akill (const char *source)
{
    notice (s_OperServ, source, RPL_HELP_START, s_OperServ);
    notice (s_OperServ, source, " ");
    notice (s_OperServ, source, "Syntax: \2AKILL ADD|DEL|LIST [Mask|Number|Option]\2");
    notice (s_OperServ, source, " ");
    notice (s_OperServ, source, "Allows you to add, remove, or list AutoKills. There are a");
    notice (s_OperServ, source, "number of parameters for each command:");
    notice (s_OperServ, source, " ");
    notice (s_OperServ, source, "\2ADD Mask|Nick [!P] [!R] [!T Expire Time] Reason\2 - The expire");
    notice (s_OperServ, source, "time is optional. If no expire time is given, the default will");
    notice (s_OperServ, source, "be used. Expire times are in the format of Days, Hours, Minutes,");
    notice (s_OperServ, source, "Seconds. For example, an expire time of 5 days, 1 hour and 30");
    notice (s_OperServ, source, "minutes would be 5d1h30m. You must give the \2!T\2 token to");
    notice (s_OperServ, source, "have an expire time understood. If the \2!R\2 token is given,");
    notice (s_OperServ, source, "OperStats will treat the mask as a realname, and will AKill");
    notice (s_OperServ, source, "any users with matching realnames. If the \2!P\2 token is given,");
    notice (s_OperServ, source, "the AKill will never expire. If both the \2!T\2 and \2!P\2 tokens are");
    notice (s_OperServ, source, "given, The \2!P\2 token will have no effect. If you give a nickname");
    notice (s_OperServ, source, "instead of a mask, OperStats will find that user's mask and");
    notice (s_OperServ, source, "AutoKill it. If the user is not online, you will have to provide");
    notice (s_OperServ, source, "a valid mask. The \2!P\2 token must always be given before the \2!R\2");
    notice (s_OperServ, source, "token, and the \2!R\2 token must always be given before the \2!T\2");
    notice (s_OperServ, source, "token.");
    notice (s_OperServ, source, " ");
    notice (s_OperServ, source, "\2DEL Mask|Number|ALL\2 - Remove an AutoKill.");
    notice (s_OperServ, source, " ");
    notice (s_OperServ, source, "\2LIST [FULL] [Match]\2 - Search for an AKill. If the");
    notice (s_OperServ, source, "first parameter is \2FULL\2, AKill reasons will be displayed,");
    notice (s_OperServ, source, "otherwise they will be omitted. If \2Match\2 is specified, it");
    notice (s_OperServ, source, "will be matched against the AKill mask and setter.");
    notice (s_OperServ, source, " ");
    notice (s_OperServ, source, "Examples: \2AKILL ADD *@*.someisp.com You are not welcome.\2");
    notice (s_OperServ, source, "          \2AKILL ADD *@*.someisp.com !T 5d1h30m You are not welcome.\2");
    notice (s_OperServ, source, "          \2AKILL ADD *@*.someisp.com !P You are not welcome.\2");
    notice (s_OperServ, source, "          \2AKILL ADD *sub7* !R Sub7 - You are not welcome.\2");
    notice (s_OperServ, source, "          \2AKILL ADD *sub7* !R !T 10d Sub7 - You are not welcome.\2");
    notice (s_OperServ, source, "          \2AKILL DEL *@*.someisp.com\2");
    notice (s_OperServ, source, "          \2AKILL DEL 25\2");
    notice (s_OperServ, source, "          \2AKILL DEL ALL\2");
    notice (s_OperServ, source, "          \2AKILL LIST\2");
    notice (s_OperServ, source, "          \2AKILL LIST *match*\2");
    notice (s_OperServ, source, "          \2AKILL LIST FULL\2");
    notice (s_OperServ, source, "          \2AKILL LIST FULL *match*\2");
    notice (s_OperServ, source, " ");
    notice (s_OperServ, source, RPL_HELP_END);
}

void operserv_help_trigger (const char *source)
{
    notice (s_OperServ, source, RPL_HELP_START, s_OperServ);
    notice (s_OperServ, source, " ");
    notice (s_OperServ, source, "Syntax: \2TRIGGER ADD|DEL|LIST [Host|Number|ALL] [Limit]");
    notice (s_OperServ, source, " ");
    notice (s_OperServ, source, "Allows you to add, remove or list Triggers. A Trigger allows");
    notice (s_OperServ, source, "the Triggered host to have the defined number of connections.");
    notice (s_OperServ, source, "This allows you to set individual limits for certain hosts, such");
    notice (s_OperServ, source, "as your network's channel and nickname services.");
    notice (s_OperServ, source, " ");
    notice (s_OperServ, source, "Examples: \2TRIGGER ADD service@example.net 20\2");
    notice (s_OperServ, source, "          \2TRIGGER DEL 1\2");
    notice (s_OperServ, source, "          \2TRIGGER DEL ALL\2");
    notice (s_OperServ, source, "          \2TRIGGER DEL service@example.net\2");
    notice (s_OperServ, source, "          \2TRIGGER LIST\2");
    notice (s_OperServ, source, " ");
    notice (s_OperServ, source, RPL_HELP_END);
}

void operserv_help_exception (const char *source)
{
    notice (s_OperServ, source, RPL_HELP_START, s_OperServ);
    notice (s_OperServ, source, " ");
    notice (s_OperServ, source, "Syntax: \2EXCEPTION ADD|DEL|LIST [Host|Number|ALL]");
    notice (s_OperServ, source, " ");
    notice (s_OperServ, source, "Allows you to add, remove or list Exceptions. An Exception allows");
    notice (s_OperServ, source, "the specified host to have total immunity to clone detection.");
    notice (s_OperServ, source, "Exceptions also override any Trigger-set limits.");
    notice (s_OperServ, source, " ");
    notice (s_OperServ, source, "Examples: \2EXCEPTION ADD service@example.net\2");
    notice (s_OperServ, source, "          \2EXCEPTION DEL 1\2");
    notice (s_OperServ, source, "          \2EXCEPTION DEL ALL\2");
    notice (s_OperServ, source, "          \2EXCEPTION DEL service@example.net\2");
    notice (s_OperServ, source, "          \2EXCEPTION LIST\2");
    notice (s_OperServ, source, " ");
    notice (s_OperServ, source, RPL_HELP_END);
}

void operserv_help_logonmsg (const char *source)
{
    notice (s_OperServ, source, RPL_HELP_START, s_OperServ);
    notice (s_OperServ, source, " ");
    notice (s_OperServ, source, "Syntax: \2LOGONMSG ADD|DEL|LIST [Text|Number|ALL]");
    notice (s_OperServ, source, " ");
    notice (s_OperServ, source, "Allows you to add, remove or list LogonMSGs. The syntax for");
    notice (s_OperServ, source, "each command is as follows:");
    notice (s_OperServ, source, " ");
    notice (s_OperServ, source, "\2ADD Text for LogonMSG\2");
    notice (s_OperServ, source, "\2DEL Number|ALL\2");
    notice (s_OperServ, source, "\2LIST\2");
    notice (s_OperServ, source, " ");
    notice (s_OperServ, source, "Due to the nature of LogonMSGs, \2DEL\2 and \2LIST\2 do not");
    notice (s_OperServ, source, "attempt any matching against the message contents.");
    notice (s_OperServ, source, " ");
    notice (s_OperServ, source, "Examples: \2LOGONMSG ADD Welcome to ExampleNet!\2");
    notice (s_OperServ, source, "          \2LOGONMSG DEL 1\2");
    notice (s_OperServ, source, "          \2LOGONMSG DEL ALL\2");
    notice (s_OperServ, source, "          \2LOGONMSG LIST\2");
    notice (s_OperServ, source, " ");
    notice (s_OperServ, source, RPL_HELP_END);
}

void shared_help_auth (const char *source)
{
    char *whoami = (operserv_on == TRUE ? s_OperServ : s_StatServ);

    notice (whoami, source, RPL_HELP_START, whoami);
    notice (whoami, source, " ");
    notice (whoami, source, "Syntax: \2AUTH NickName Password\2");
    notice (whoami, source, " ");
    notice (whoami, source, "Allows you to authenticate for SRA access. Once you have");
    notice (whoami, source, "authenticated, you will be recognized as an SRA until you");
    notice (whoami, source, "disconnect from the network or \2DEAUTH\2.");
    notice (whoami, source, " ");
    notice (whoami, source, "Example: \2AUTH SRANick SRAPass\2");
    notice (whoami, source, " ");
    notice (whoami, source, RPL_HELP_END);
}

void shared_help_deauth (const char *source)
{
    char *whoami = (operserv_on == TRUE ? s_OperServ : s_StatServ);

    notice (whoami, source, RPL_HELP_START, whoami);
    notice (whoami, source, " ");
    notice (whoami, source, "Syntax: \2DEAUTH\2");
    notice (whoami, source, " ");
    notice (whoami, source, "Causes you to no longer be recognized as an SRA. You will");
    notice (whoami, source, "need to re-\2AUTH\2 to regain SRA access.");
    notice (whoami, source, " ");
    notice (whoami, source, "Example: \2DEAUTH\2");
    notice (whoami, source, " ");
    notice (whoami, source, RPL_HELP_END);
}

void shared_help_shutdown (const char *source)
{
    char *whoami = (operserv_on == TRUE ? s_OperServ : s_StatServ);

    notice (whoami, source, RPL_HELP_START, whoami);
    notice (whoami, source, " ");
    notice (whoami, source, "Syntax: \2SHUTDOWN [NOSAVE] [Reason]\2");
    notice (whoami, source, " ");
    notice (whoami, source, "Causes OperStats to terminate. If you give the NOSAVE token,");
    notice (whoami, source, "the DBs will not be saved. Otherwise, they will be updated before");
    notice (whoami, source, "OperStats shuts down. If you give a reason, this will be used in a");
    notice (whoami, source, "GlobOps and a log entry.");
    notice (whoami, source, " ");
    notice (whoami, source, "Examples: \2SHUTDOWN\2");
    notice (whoami, source, "          \2SHUTDOWN NOSAVE Reason\2");
    notice (whoami, source, "          \2SHUTDOWN Reason\2");
    notice (whoami, source, " ");
    notice (whoami, source, RPL_HELP_END);
}

void shared_help_restart (const char *source)
{
    char *whoami = (operserv_on == TRUE ? s_OperServ : s_StatServ);

    notice (whoami, source, RPL_HELP_START, whoami);
    notice (whoami, source, " ");
    notice (whoami, source, "Syntax: \2RESTART [NOSAVE] [Reason]\2");
    notice (whoami, source, " ");
    notice (whoami, source, "Causes OperStats to restart. If you give the NOSAVE token,");
    notice (whoami, source, "the DBs will not be saved. Otherwise, they will be updated before");
    notice (whoami, source, "OperStats shuts down. If you give a reason, this will be used in a");
    notice (whoami, source, "GlobOps and a log entry.");
    notice (whoami, source, " ");
    notice (whoami, source, "Examples: \2RESTART\2");
    notice (whoami, source, "          \2RESTART NOSAVE Reason\2");
    notice (whoami, source, "          \2RESTART Reason\2");
    notice (whoami, source, " ");
    notice (whoami, source, RPL_HELP_END);
}

void shared_help_search (const char *source)
{
    char *whoami = (operserv_on == TRUE ? s_OperServ : s_StatServ);

    notice (whoami, source, RPL_HELP_START, whoami);
    notice (whoami, source, " ");
    notice (whoami, source, "Syntax: \2SEARCH MatchText [Num]\2");
    notice (whoami, source, " ");
    notice (whoami, source, "Allows you to search OperStats' logfiles for specific text.");
    notice (whoami, source, "If \2Num\2 is specified, that amount of matches will be shown.");
    notice (whoami, source, "\2Num\2 defaults to 50, and cannot be more than 250.");
    notice (whoami, source, " ");
    notice (whoami, source, "Example: \2SEARCH *akill* 25\2");
    notice (whoami, source, " ");
    notice (whoami, source, RPL_HELP_END);
}

#ifdef RAWINJECT
void shared_help_raw (const char *source)
{
    char *whoami = (operserv_on == TRUE ? s_OperServ : s_StatServ);

    notice (whoami, source, RPL_HELP_START, whoami);
    notice (whoami, source, " ");
    notice (whoami, source, "Syntax: \2RAW Data\2");
    notice (whoami, source, " ");
    notice (whoami, source, "Sends information to OperStats' uplink. Syntax is important.");
    notice (whoami, source, "There is no limit to what you can do with \2RAW\2, provided");
    notice (whoami, source, "your IRCd supports it.");
    notice (whoami, source, " ");
    notice (whoami, source, "The \2RAW\2 command is not supported in any way.");
    notice (whoami, source, " ");
    notice (whoami, source, "Example: \2RAW SVSNICK OldNick NewNick :0\2");
    notice (whoami, source, " ");
    notice (whoami, source, RPL_HELP_END);
}

void shared_help_inject (const char *source)
{
    char *whoami = (operserv_on == TRUE ? s_OperServ : s_StatServ);

    notice (whoami, source, RPL_HELP_START, whoami);
    notice (whoami, source, " ");
    notice (whoami, source, "Syntax: \2INJECT Data\2");
    notice (whoami, source, " ");
    notice (whoami, source, "Fakes information from OperStats' uplink. Only certain information");
    notice (whoami, source, "will be processed. See process.c for examples on what types of");
    notice (whoami, source, "information will be processed. Note that misuse of this command");
    notice (whoami, source, "(such as injecting a QUIT from a user) WILL cause OperStats to be");
    notice (whoami, source, "desync'd from the network and may cause crashes.");
    notice (whoami, source, " ");
    notice (whoami, source, "The \2INJECT\2 command is not supported in any way.");
    notice (whoami, source, " ");
    notice (whoami, source, "Example: \2INJECT :User PRIVMSG StatServ :STATS\2");
    notice (whoami, source, " ");
    notice (whoami, source, RPL_HELP_END);
}
#endif /* RAWINJECT */

void shared_help_debug (const char *source)
{
    char *whoami = (operserv_on == TRUE ? s_OperServ : s_StatServ);

    notice (whoami, source, RPL_HELP_START, whoami);
    notice (whoami, source, " ");
    notice (whoami, source, "Syntax: \2DEBUG Level\2");
    notice (whoami, source, " ");
    notice (whoami, source, "Sets the debugging level. There are 4 debug mode levels:");
    notice (whoami, source, " ");
    notice (whoami, source, "    \2Level 0\2: No debug logging (disabled)");
    notice (whoami, source, "    \2Level 1\2: All server<->server traffic is logged.");
    notice (whoami, source, "    \2Level 2\2: Some function calls are logged.");
    notice (whoami, source, "    \2Level 3\2: Both server<->server traffic and some function calls are logged");
    notice (whoami, source, " ");
    notice (whoami, source, "Logging will be done in debug.log, not %s", LOGFILE);
    notice (whoami, source, " ");
    notice (whoami, source, "Example: \2DEBUG 3\2");
    notice (whoami, source, " ");
    notice (whoami, source, RPL_HELP_END);
}

void shared_help_update (const char *source)
{
    char *whoami = (operserv_on == TRUE ? s_OperServ : s_StatServ);

    notice (whoami, source, RPL_HELP_START, whoami);
    notice (whoami, source, " ");
    notice (whoami, source, "Syntax: \2UPDATE\2");
    notice (whoami, source, " ");
    notice (whoami, source, "Forces OperStats to save the DBs to disk. This will also");
    notice (whoami, source, "reset the sync timer.");
    notice (whoami, source, " ");
    notice (whoami, source, "Example: \2UPDATE\2");
    notice (whoami, source, " ");
    notice (whoami, source, RPL_HELP_END);
}

void shared_help_rehash (const char *source)
{
    char *whoami = (operserv_on == TRUE ? s_OperServ : s_StatServ);

    notice (whoami, source, RPL_HELP_START, whoami);
    notice (whoami, source, " ");
    notice (whoami, source, "Syntax: \2REHASH\2");
    notice (whoami, source, " ");
    notice (whoami, source, "Re-Reads %s. If you have any invalid settings, this", CONFIGFILE);
    notice (whoami, source, "will cause OperStats to shut down. The DBs will be saved to disk");
    notice (whoami, source, "beforehand in case this happens.");
    notice (whoami, source, " ");
    notice (whoami, source, "Example: \2REHASH\2");
    notice (whoami, source, " ");
    notice (whoami, source, RPL_HELP_END);
}

void shared_help_settings (const char *source)
{
    char *whoami = (operserv_on == TRUE ? s_OperServ : s_StatServ);

    notice (whoami, source, RPL_HELP_START, whoami);
    notice (whoami, source, " ");
    notice (whoami, source, "Syntax: \2SETTINGS\2");
    notice (whoami, source, " ");
    notice (whoami, source, "Shows various OperStats settings as defined in %s.", CONFIGFILE);
    notice (whoami, source, " ");
    notice (whoami, source, "Example: \2SETTINGS\2");
    notice (whoami, source, " ");
    notice (whoami, source, RPL_HELP_END);
}
